@@ -2,6 +2,7 @@ import contextlib
 
 import asyncpg
 
+from ..pg import server_settings
 from ..restore import RestoreIo, RestoreParams, restore
 from .common import open_bytes_read
 
@@ -14,7 +15,11 @@ async def restore_main(args):
     )
 
     async with asyncpg.create_pool(
-        min_size=0, max_size=args.jobs, max_inactive_connection_lifetime=10
+        min_size=0,
+        max_size=args.jobs,
+        max_inactive_connection_lifetime=10,
+        server_settings=server_settings(),
+        statement_cache_size=0,
     ) as pool:
         io = RestoreIo(
             conn=lambda: pool.acquire(), input=lambda: open_bytes_read(args.input)
